@@ -54,7 +54,7 @@ class AbstractRunner(ABC):
 
 class  MixerRunner(AbstractRunner):
     def runTrial(self, saver, seed, n, s, s_eval, calibration_step, signal_type, idios_string):
-        continuous_saving_key, two_states_saving_key, two_states_saving_key_lo, three_states_saving_key, three_states_saving_key_lo = saver.create_saving_key(seed, n, s, s_eval, calibration_step, signal_type, idios_string)
+        continuous_saving_key, two_states_saving_key, two_states_saving_key_lo, three_states_saving_key, three_states_saving_key_lo, idios = saver.create_saving_key(seed, n, s, s_eval, calibration_step, signal_type, idios_string)
 
         check_run_existence, table_number = saver.checkRunExistence(continuous_saving_key)
         exhaustive_check_run_existence, exhaustive_table_number = saver.exhaustiveCheckRunExistence(continuous_saving_key)
