@@ -17,7 +17,7 @@ import random
 import string
 
 class SignalParalleLauncher():
-    def __init__(self,starting_date = None, running_date = None, drop_token='', dropbox_backup=True, local_root_directory='../data',user='napoleon',underlying=None,frequence=None,algo=None,db_path_suffix = '_alphas.sqlite', triggers = [True], transaction_costs = [True], normalizations = [False], signal_idiosyncratic_paramaters=[None], table_max_size = 2000):
+    def __init__(self,starting_date = None, running_date = None, drop_token='', dropbox_backup=True, local_root_directory='../data',user='napoleon',underlying=None,frequence=None,algo=None,db_path_suffix = '_alphas.sqlite', triggers = [True], transaction_costs = [True], normalizations = [False], modulators =[1.] ,signal_idiosyncratic_paramaters=[None], table_max_size = 2000):
         self.starting_date=starting_date
         self.running_date=running_date
         self.args = []
@@ -27,16 +27,17 @@ class SignalParalleLauncher():
         for trigger in triggers:
             for transaction_cost in transaction_costs:
                 for normalization in normalizations:
-                    for signal_type, params  in signal_idiosyncratic_paramaters.items():
-                        for param in params:
-                            rand_hash= ''.join(random.choice(string.ascii_lowercase) for i in range(4))
-                            # problem due to json serialization
-                            rand_hash = rand_hash.replace('cc','wc')
-                            rand_hash = rand_hash.replace('dd','wd')
-                            rand_hash = rand_hash.replace('qq','wq')
-                            rand_hash = rand_hash.replace('aa','wa')
-                            self.args.append((self,rand_hash,trigger,signal_type, json.dumps(param, sort_keys=True), transaction_cost, normalization))
-                            self.key_args.append((rand_hash, trigger, signal_type, json.dumps(param, sort_keys=True),transaction_cost, normalization))
+                    for modulator in modulators:
+                        for signal_type, params  in signal_idiosyncratic_paramaters.items():
+                            for param in params:
+                                rand_hash= ''.join(random.choice(string.ascii_lowercase) for i in range(4))
+                                # problem due to json serialization
+                                rand_hash = rand_hash.replace('cc','wc')
+                                rand_hash = rand_hash.replace('dd','wd')
+                                rand_hash = rand_hash.replace('qq','wq')
+                                rand_hash = rand_hash.replace('aa','wa')
+                                self.args.append((self,rand_hash,trigger,signal_type, json.dumps(param, sort_keys=True), transaction_cost, normalization, modulator))
+                                self.key_args.append((rand_hash, trigger, signal_type, json.dumps(param, sort_keys=True),transaction_cost, normalization, modulator))
 
         self.key_args.sort()
         self.counter = 1
@@ -60,14 +61,15 @@ class SignalParalleLauncher():
         self.empty_runs_to_investigate = []
         self.dbx = dropbox_file_saver.NaPoleonDropboxConnector(drop_token=drop_token,dropbox_backup=dropbox_backup)
 
-    def create_saving_key(self,seed, trigger, signal_type, idios_string, transaction_costs, normalization):
+    def create_saving_key(self,seed, trigger, signal_type, idios_string, transaction_costs, normalization, modulator):
         idios = json.loads(idios_string)
         common_params = {
             'seed': seed,
             'trigger': trigger,
             'signal_type': signal_type,
             'transaction_costs': transaction_costs,
-            'normalization': normalization
+            'normalization': normalization,
+            'modulator': modulator
         }
         common_params.update(idios)
         saving_key = json.dumps(common_params, sort_keys=True)
