@@ -79,10 +79,10 @@ def pair_handling_message(fetcher, msg, compute_minute_signal=True, compute_day_
                     ia_day_signal = fetcher.launchDaySequential()
 
             if (len(fetcher.day_np.shape) > 1 and len(fetcher.day_np) > 3):
-                print('last three days')
-                print(fetcher.day_np[-3:, :])
-
-            print('day ia new signal computation for the bot ' + str(ia_day_signal))
+                #print('last three days')
+                #print(fetcher.day_np[-3:, :])
+                print('day ia new signal computation for the bot ' + str(ia_day_signal))
+            print('updating bot position for pair '+ str(fetcher.pair) + ' and signal '+str(ia_day_signal))
             fetcher.bot.update_position(fetcher.pair, ia_day_signal)
 
             if fetcher.hour_np is not None and len(fetcher.hour_np)>0:
@@ -92,8 +92,7 @@ def pair_handling_message(fetcher, msg, compute_minute_signal=True, compute_day_
                 fetcher.reset_hour_np_to_lookback_window()
 
             if fetcher.day_np is not None and len(fetcher.day_np)>0:
-                print('persisting minutes dataframe for the previous hour')
-                #fetcher.upload_last_hour_60_minutes_dataframe()
+                print('persisting days dataframe')
                 fetcher.upload_days_signals_dataframe()
 
 
@@ -137,16 +136,15 @@ def pair_handling_message(fetcher, msg, compute_minute_signal=True, compute_day_
                 fetcher.hour_np = np.vstack((fetcher.hour_np, hour_new_data))
 
             if (len(fetcher.hour_np.shape)>1 and len(fetcher.hour_np)>3):
-                print('last three hours')
-                print(fetcher.hour_np[-3:,:])
+                #print('last three hours')
+                #print(fetcher.hour_np[-3:,:])
+                print('no hourly ia signal yet')
             #fetcher.minute_df.loc[len(fetcher.minute_df)] = new_data
             if fetcher.minute_np is not None and len(fetcher.minute_np)>0:
                 print('persisting minutes dataframe for the previous hour')
-                #fetcher.upload_last_hour_60_minutes_dataframe()
                 fetcher.upload_last_hour_60_minutes_signals_dataframe()
                 fetcher.reset_minute_np_to_lookback_window()
-
-        # we clear every former minutes
+        # we clear every former hours
         hour_high_dict.clear()
         hour_low_dict.clear()
         hour_volu_dict.clear()
@@ -192,10 +190,9 @@ def pair_handling_message(fetcher, msg, compute_minute_signal=True, compute_day_
                 else:
                     ia_minute_signal = fetcher.launchMinuteSequential()
             if (len(fetcher.minute_np.shape)>1 and len(fetcher.minute_np)>3):
-                print('last three minutes '+minute_name)
-                print(fetcher.minute_np[-3:,:])
+                #print('last three minutes '+minute_name)
+                #print(fetcher.minute_np[-3:,:])
                 print('minute ia signal ' + str(ia_minute_signal))
-            #fetcher.minute_df.loc[len(fetcher.minute_df)] = new_data
         # we clear every former minutes
         high_dict.clear()
         low_dict.clear()
@@ -447,7 +444,7 @@ class RealTimeSignalEnsemblingParalleLauncher():
         print(aggregated_df.shape)
         return aggregated_df
 
-    def get_aws_last_past_days(self, nb_last_days = 50):
+    def get_aws_last_past_days(self, nb_last_days = 1):
         date_now = datetime.utcnow()
         files_to_fetch = []
 
@@ -502,7 +499,8 @@ class RealTimeSignalEnsemblingParalleLauncher():
             daily_df = napoleon_connector.fetch_crypto_daily_data(ssj=self.underlying, local_root_directory=self.local_root_directory,
                                                                    daily_return_pkl_filename_suffix='_daily_temp.pkl',
                                                                    refetch_all=True,
-                                                                   daily_crypto_starting_day=starting_date)
+                                                                   daily_crypto_starting_day=starting_date,
+                                                                  daily_crypto_ending_day=running_date)
             daily_df = daily_df.sort_index()
             print('time range for daily recomputation')
             print(max(daily_df.index))
@@ -527,23 +525,17 @@ class RealTimeSignalEnsemblingParalleLauncher():
             ## idiosyncratic run itself
             run_json_string = signal_utility.recover_to_sql_column_format(me_signal)
             params = json.loads(run_json_string)
-
-
             normalization = params['normalization']
             transaction_costs = params['transaction_costs']
             trigger = params['trigger']
-
             signal_type = params['signal_type']
             if normalization and not signal_generator.is_signal_continuum(signal_type):
                 return
-
             params = json.loads(run_json_string)
             salty = str(int(hashlib.sha1(run_json_string.encode('utf-8')).hexdigest(), 16) % (10 ** 8))
             params = json.loads(run_json_string)
             signal_column = params['signal_type'] + str(params['trigger']) + salty
-
             mapping_dictionary[me_signal]=signal_column
-
             if signal_type == 'long_only':
                 freqly_df['signal']=1.
             else:
@@ -557,10 +549,12 @@ class RealTimeSignalEnsemblingParalleLauncher():
                 freqly_df, _ = signal_utility.reconstitute_signal_perf(data = freqly_df, transaction_cost = transaction_costs, normalization = normalization)
 
             if cumulated_signals is None:
-                cumulated_signals = freqly_df[['close','high','low','open','volumefrom','signal']].copy()
-                cumulated_signals = cumulated_signals.rename(columns={'signal': signal_column})
+                freqly_df['signal_not_shifted'] = freqly_df['signal'].shift(-1)
+                cumulated_signals = freqly_df[['close','high','low','open','volumefrom','signal_not_shifted']].copy()
+                cumulated_signals = cumulated_signals.rename(columns={'signal_not_shifted': signal_column})
             else :
-                cumulated_signals[signal_column]=freqly_df['signal'].copy()
+                freqly_df['signal_not_shifted'] = freqly_df['signal'].shift(-1)
+                cumulated_signals[signal_column]=freqly_df['signal_not_shifted'].copy()
             counter=counter+1
 
         print('recomputation done')
@@ -568,13 +562,16 @@ class RealTimeSignalEnsemblingParalleLauncher():
         cumulated_signals['date'] = pd.to_datetime(cumulated_signals.index)
         cumulated_signals['ts'] = cumulated_signals['date'].values.astype(np.int64) // 10 ** 9
 
+        up_to_date = up_to_date - timedelta(days=1)
+        cumulated_signals=cumulated_signals[cumulated_signals.index<=up_to_date]
+
         backed_up_signal_histo_name =  up_to_date.strftime('%d_%b_%Y')+'_'+self.underlying+'_'+self.backed_up_signal_histo_suffix
         saving_path = self.local_root_directory+backed_up_signal_histo_name
         print('saving histo recomputation to '+backed_up_signal_histo_name)
         cumulated_signals.to_pickle(saving_path)
 
     def reload_daily_histo(self):
-        upto_date = datetime.now()
+        upto_date = datetime.now() - timedelta(days=1)
         backed_up_signal_histo_name =  upto_date.strftime('%d_%b_%Y')+'_'+self.underlying+'_'+self.backed_up_signal_histo_suffix
         saving_path = self.local_root_directory+backed_up_signal_histo_name
         print('loading histo recomputation to '+backed_up_signal_histo_name)
